==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProberSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ProberSpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<A>{
  public ProberSpecFluentImpl() {
  }
  public ProberSpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance) {
    this.withPath(instance.getPath()); 
    this.withScheme(instance.getScheme()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String path;
  private java.lang.String scheme;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getScheme() {
    return this.scheme;
  }
  public A withScheme(java.lang.String scheme) {
    this.scheme=scheme; return (A) this;
  }
  public java.lang.Boolean hasScheme() {
    return this.scheme != null;
  }
  
  /**
   * Method is deprecated. use withScheme instead.
   */
  @java.lang.Deprecated
  public A withNewScheme(java.lang.String arg0) {
    return (A)withScheme(new String(arg0));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProberSpecFluentImpl that = (ProberSpecFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (scheme != null ? !scheme.equals(that.scheme) :that.scheme != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  scheme,  url,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProberSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ProberSpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<A>{
  public ProberSpecFluentImpl() {
  }
  public ProberSpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance) {
    this.withPath(instance.getPath()); 
    this.withProxyUrl(instance.getProxyUrl()); 
    this.withScheme(instance.getScheme()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String path;
  private java.lang.String proxyUrl;
  private java.lang.String scheme;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getProxyUrl() {
    return this.proxyUrl;
  }
  public A withProxyUrl(java.lang.String proxyUrl) {
    this.proxyUrl=proxyUrl; return (A) this;
  }
  public java.lang.Boolean hasProxyUrl() {
    return this.proxyUrl != null;
  }
  
  /**
   * Method is deprecated. use withProxyUrl instead.
   */
  @java.lang.Deprecated
  public A withNewProxyUrl(java.lang.String arg0) {
    return (A)withProxyUrl(new String(arg0));
  }
  public java.lang.String getScheme() {
    return this.scheme;
  }
  public A withScheme(java.lang.String scheme) {
    this.scheme=scheme; return (A) this;
  }
  public java.lang.Boolean hasScheme() {
    return this.scheme != null;
  }
  
  /**
   * Method is deprecated. use withScheme instead.
   */
  @java.lang.Deprecated
  public A withNewScheme(java.lang.String arg0) {
    return (A)withScheme(new String(arg0));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProberSpecFluentImpl that = (ProberSpecFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (proxyUrl != null ? !proxyUrl.equals(that.proxyUrl) :that.proxyUrl != null) return false;
    if (scheme != null ? !scheme.equals(that.scheme) :that.scheme != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  proxyUrl,  scheme,  url,  additionalProperties,  super.hashCode());
  }
  
}
